<?xml version="1.0"?>
<app>

<category>
Language
</category>

<name>
Japanese_Input_fcitx
</name>

<description>
   <am>Japanese fcitx</am>
   <ar>Japanese fcitx</ar>
   <bg>Japanese fcitx</bg>
   <ca>Fcitx en italià</ca>
   <cs>Japanese fcitx</cs>
   <da>Japansk fcitx</da>
   <de>Japanisch Fcitx</de>
   <el>Ιαπωνικά fcitx</el>
   <en>Japanese fcitx</en>
   <es>Fcitx Japonés</es>
   <et>Japanese fcitx</et>
   <eu>Japanese fcitx</eu>
   <fa>Japanese fcitx</fa>
   <fi>Japanese fcitx</fi>
   <fr>Japonais fcitx</fr>
   <he_IL>Japanese fcitx</he_IL>
   <hi>Japanese fcitx</hi>
   <hr>Japanese fcitx</hr>
   <hu>Japanese fcitx</hu>
   <id>Japanese fcitx</id>
   <is>Japanese fcitx</is>
   <it>Fcitx per la lingua giapponese</it>
   <ja_JP>Japanese fcitx</ja_JP>
   <ja>Japanese fcitx</ja>
   <kk>Japanese fcitx</kk>
   <ko>Japanese fcitx</ko>
   <lt>Japonų fcitx</lt>
   <mk>Japanese fcitx</mk>
   <nb>Japanese fcitx</nb>
   <nl>Japanse fcitx</nl>
   <pl>Japoński fcitx</pl>
   <pt_BR>Japonês fcitx</pt_BR>
   <pt>Japonês fcitx</pt>
   <ro>Japanese fcitx</ro>
   <ru>Japanese fcitx</ru>
   <sk>Japanese fcitx</sk>
   <sl>Japanese fcitx</sl>
   <sq>Japanese fcitx</sq>
   <sr>Japanese fcitx</sr>
   <sv>Japansk fcitx</sv>
   <tr>Japanese fcitx</tr>
   <uk>Japanese fcitx</uk>
   <zh_CN>Japanese fcitx</zh_CN>
   <zh_TW>Japanese fcitx</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>

</preinstall>

<install_package_names>
fcitx
fcitx-config-gtk
fcitx-frontend-all
fcitx-frontend-fbterm
fcitx-tools
fcitx-ui-classic
fcitx-ui-light
fcitx-anthy
fcitx-mozc
fcitx-table-all
fcitx-config-gtk2
fcitx-frontend-gtk2
fcitx-frontend-gtk3
fcitx-frontend-qt4
fcitx-frontend-qt5
im-config
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
fcitx
fcitx-config-gtk
fcitx-frontend-all
fcitx-frontend-fbterm
fcitx-tools
fcitx-ui-classic
fcitx-ui-light
fcitx-anthy
fcitx-mozc
fcitx-table-all
fcitx-config-gtk2
fcitx-frontend-gtk2
fcitx-frontend-gtk3
fcitx-frontend-qt4
fcitx-frontend-qt5
im-config
</uninstall_package_names>
</app>
